MethodChannelSoundEffect class

An implementation of SoundEffectPlatform that uses method channels.

Inheritance

Constructors

MethodChannelSoundEffect()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize({required int maxStreams}) → Future<void>
override
load(String soundId, String path) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
play(String soundId, {double volume = 1.0}) → Future<void>
override
release() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited